from distutils.core import setup

setup(name='phys_benchmark',
      version='2.1',
      description='Benchamrking MD on PHYS MPU cluster',
      author='Adelie Louet',
      author_email='adelie.louet@biophys.mpg.de',
      url='https://github.com/louetadelie1/benchmark_phys.git/',
      packages=[],
     )
